## Changelog

1.0.4
- fix ansible implementation and tests


1.0.2, 1.0.3
- doc updates


1.0.1 breaking changes but still initial 1.0 release
- rename hits EncryptedSecret and DecryptedSecret


1.0 release
- basic functionality
